@@ -1,7 +1,10 @@
 # -*- coding:utf-8 -*-
 import copy
-
-from commFunction import *
+import sys
+import  os
+from os import path
+sys.path.append(os.path.dirname(path.dirname(__file__)))
+from commFunction import getip,log_time,global_result,sftp_connect,sftp_put,sftp_disconnect,get_file_path
 import shutil
 from  socketClient import SocketClient
 import datetime
