@@ -1,5 +1,10 @@
 # -*- coding:utf-8 -*-
-from commFunction import *
+import sys
+import  os,time
+from os import path
+import copy
+sys.path.append(os.path.dirname(path.dirname(__file__)))
+from commFunction import global_result,sftp_connect,sftp_get,sftp_disconnect,constMosResult
 import shutil
 from  socketClient import SocketClient
 from POLQA import startvqt
@@ -16,7 +21,8 @@ def exec_polqa_test():
         curruslt = socket.sender(curdata)
         print(curruslt)
         socket.close()
-        if curruslt['job'] == None:
+        print(curruslt['job'])
+        if curruslt['job'] is None or str(curruslt['job']) == 'null':
             continue
 
         #try:
