@@ -10,12 +10,14 @@ from .resample.resampler import resample
 from operator import methodcaller
 from .computeAudioQuality.mainProcess import computeAudioQuality
 
+from ctypes import  *
 
-def compute_audio_quality(metrics,testFile=None,refFile=None,cleFile=None,samplerate=16000,bitwidth=2,channel=1,refOffset=0,testOffset=0):
+def compute_audio_quality(metrics,testFile=None,refFile=None,cleFile=None,samplerate=16000,bitwidth=2,channel=1,refOffset=0,testOffset=0,maxComNLevel =c_double(-48.0),speechPauseLevel=c_double(-35.0)):
     """
-
+            self.maxComNLevel = c_double(kwargs['maxComNLevel'])
+        self.speechPauseLevel = c_double(kwargs['speechPauseLevel'])
     :param metrics: G160/P563/POLQA/PESQ/STOI/STI/PEAQ/SDR/SII/LOUDNESS，必选项
-    # g160 无采样率限制；  WAV/PCM输入 ；三端输入: clean、ref、test；无时间长度要求；
+    # G160 无采样率限制；  WAV/PCM输入 ；三端输入: clean、ref、test；无时间长度要求；
     # P563 8000hz(其他采样率会强制转换到8khz)；  WAV/PCM输入 ；单端输入: test；时长 < 20s；
     # POLQA 窄带模式  8k  超宽带模式 48k ；WAV/PCM输入 ；双端输入：ref、test；时长 < 20s；
     # PESQ 窄带模式  8k   宽带模式 16k ；WAV/PCM输入 ；双端输入：ref、test；时长 < 20s；
@@ -43,8 +45,11 @@ def compute_audio_quality(metrics,testFile=None,refFile=None,cleFile=None,sample
         'bitwidth':bitwidth,
         'channel':channel,
         'refOffset':refOffset,
-        'testOffset':testOffset
+        'testOffset':testOffset,
+        'maxComNLevel':maxComNLevel,
+        "speechPauseLevel":speechPauseLevel
     }
     comAuQUA = computeAudioQuality(**paraDicts)
     return methodcaller(metrics)(comAuQUA)
 
+
